diff --git a/src/wp-includes/post-template.php b/src/wp-includes/post-template.php
index 3734373..65392f6 100644
--- a/src/wp-includes/post-template.php
+++ b/src/wp-includes/post-template.php
@@ -1023,17 +1023,19 @@ function the_meta() {
 				continue;
 			$values = array_map('trim', get_post_custom_values($key));
 			$value = implode($values,', ');
+			$separator = _x( ': ', 'separator between key and value' );
 
 			/**
 			 * Filters the HTML output of the li element in the post custom fields list.
 			 *
 			 * @since 2.2.0
 			 *
 			 * @param string $html  The HTML output for the li element.
 			 * @param string $key   Meta key.
 			 * @param string $value Meta value.
 			 */
-			echo apply_filters( 'the_meta_key', "<li><span class='post-meta-key'>$key:</span> $value</li>\n", $key, $value );
+			echo apply_filters( 'the_meta_key', "<li><span class='post-meta-key'>{$key}{$separator}</span>{$value}</li>\n", $key, $separator, $value);
 		}
 		echo "</ul>\n";
 	}
@@ -1023,17 +1023,19 @@ function the_meta() {
 			 * @since 2.2.0
 			 *
-			 * @param string $html  The HTML output for the li element.
-			 * @param string $key   Meta key.
-			 * @param string $value Meta value.
+			 * @param string $html  	The HTML output for the li element.
+			 * @param string $key   	Meta key.
+			 * @param string $separator	Separator.
+			 * @param string $value 	Meta value.
 			 */
